<?php

// list of available fonts

return array(

'Arial' => array(
	'family' => 'Arial, sans-serif',
	'weights' => array( '300', '300 italic', 'normal', 'italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic' ),
),
'Verdana' => array(
	'family' => 'Verdana, Geneva, sans-serif',
	'weights' => array( '300', '300 italic', 'normal', 'italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic' ),
),
'Georgia' => array(
	'family' => 'Georgia, serif',
	'weights' => array( '300', '300 italic', 'normal', 'italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic' ),
),
'Helvetica' => array(
	'family' => 'Helvetica, Arial, serif',
	'weights' => array( '300', '300 italic', 'normal', 'italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic' ),
),
'Tahoma' => array(
	'family' => 'Tahoma, Geneva, Verdana, sans-serif',
	'weights' => array( '300', '300 italic', 'normal', 'italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic' ),
),
'Trebuchet MS' => array(
	'family' => '"Trebuchet MS", Verdana, sans-serif',
	'weights' => array( '300', '300 italic', 'normal', 'italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic' ),
),
'Calibri' => array(
	'family' => 'Calibri, Candara, Segoe, Optima, sans-serif',
	'weights' => array( '300', '300 italic', 'normal', 'italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic' ),
),
'Candara' => array(
	'family' => 'Candara, Calibri, Segoe, Optima, sans-serif',
	'weights' => array( '300', '300 italic', 'normal', 'italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic' ),
),
'Geneva' => array(
	'family' => 'Geneva, Tahoma, Verdana, sans-serif',
	'weights' => array( '300', '300 italic', 'normal', 'italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic' ),
),
'Impact' => array(
	'family' => 'Impact, Charcoal, sans-serif',
	'weights' => array( '300', '300 italic', 'normal', 'italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic' ),
),

'-- Google fonts --' => array(
	'family' => '',
),


'ABeeZee' => array(
	'family'  => 'ABeeZee',
	'weights' => array('normal', 'italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Abel' => array(
	'family'  => 'Abel',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Abhaya Libre' => array(
	'family'  => 'Abhaya Libre',
	'weights' => array('normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic'),
	'subsets' => array('sinhala', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Abril Fatface' => array(
	'family'  => 'Abril Fatface',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Aclonica' => array(
	'family'  => 'Aclonica',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Acme' => array(
	'family'  => 'Acme',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Actor' => array(
	'family'  => 'Actor',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Adamina' => array(
	'family'  => 'Adamina',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Advent Pro' => array(
	'family'  => 'Advent Pro',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('greek', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Aguafina Script' => array(
	'family'  => 'Aguafina Script',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Akronim' => array(
	'family'  => 'Akronim',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Aladin' => array(
	'family'  => 'Aladin',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Alata' => array(
	'family'  => 'Alata',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Alatsi' => array(
	'family'  => 'Alatsi',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Aldrich' => array(
	'family'  => 'Aldrich',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Alef' => array(
	'family'  => 'Alef',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('hebrew', 'latin'),
	'gf'      => true,
),
'Alegreya' => array(
	'family'  => 'Alegreya',
	'weights' => array('normal', 'italic', '500', '500 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('greek', 'vietnamese', 'greek-ext', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Alegreya SC' => array(
	'family'  => 'Alegreya SC',
	'weights' => array('normal', 'italic', '500', '500 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('greek', 'vietnamese', 'greek-ext', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Alegreya Sans' => array(
	'family'  => 'Alegreya Sans',
	'weights' => array('100', '100 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('greek', 'vietnamese', 'greek-ext', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Alegreya Sans SC' => array(
	'family'  => 'Alegreya Sans SC',
	'weights' => array('100', '100 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('greek', 'vietnamese', 'greek-ext', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Aleo' => array(
	'family'  => 'Aleo',
	'weights' => array('300', '300 italic', 'normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Alex Brush' => array(
	'family'  => 'Alex Brush',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Alfa Slab One' => array(
	'family'  => 'Alfa Slab One',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Alice' => array(
	'family'  => 'Alice',
	'weights' => array('normal'),
	'subsets' => array('cyrillic-ext', 'latin', 'cyrillic'),
	'gf'      => true,
),
'Alike' => array(
	'family'  => 'Alike',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Alike Angular' => array(
	'family'  => 'Alike Angular',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Allan' => array(
	'family'  => 'Allan',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Allerta' => array(
	'family'  => 'Allerta',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Allerta Stencil' => array(
	'family'  => 'Allerta Stencil',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Allura' => array(
	'family'  => 'Allura',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Almarai' => array(
	'family'  => 'Almarai',
	'weights' => array('300', '300 italic', 'normal', 'bold', 'bold italic', '800', '800 italic'),
	'subsets' => array('arabic'),
	'gf'      => true,
),
'Almendra' => array(
	'family'  => 'Almendra',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Almendra Display' => array(
	'family'  => 'Almendra Display',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Almendra SC' => array(
	'family'  => 'Almendra SC',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Amarante' => array(
	'family'  => 'Amarante',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Amaranth' => array(
	'family'  => 'Amaranth',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Amatic SC' => array(
	'family'  => 'Amatic SC',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('vietnamese', 'hebrew', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Amethysta' => array(
	'family'  => 'Amethysta',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Amiko' => array(
	'family'  => 'Amiko',
	'weights' => array('normal', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('devanagari', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Amiri' => array(
	'family'  => 'Amiri',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('arabic', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Amita' => array(
	'family'  => 'Amita',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('devanagari', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Anaheim' => array(
	'family'  => 'Anaheim',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Andada' => array(
	'family'  => 'Andada',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Andika' => array(
	'family'  => 'Andika',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Angkor' => array(
	'family'  => 'Angkor',
	'weights' => array('normal'),
	'subsets' => array('khmer'),
	'gf'      => true,
),
'Annie Use Your Telescope' => array(
	'family'  => 'Annie Use Your Telescope',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Anonymous Pro' => array(
	'family'  => 'Anonymous Pro',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('greek', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Antic' => array(
	'family'  => 'Antic',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Antic Didone' => array(
	'family'  => 'Antic Didone',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Antic Slab' => array(
	'family'  => 'Antic Slab',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Anton' => array(
	'family'  => 'Anton',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Arapey' => array(
	'family'  => 'Arapey',
	'weights' => array('normal', 'italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Arbutus' => array(
	'family'  => 'Arbutus',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Arbutus Slab' => array(
	'family'  => 'Arbutus Slab',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Architects Daughter' => array(
	'family'  => 'Architects Daughter',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Archivo' => array(
	'family'  => 'Archivo',
	'weights' => array('normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Archivo Black' => array(
	'family'  => 'Archivo Black',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Archivo Narrow' => array(
	'family'  => 'Archivo Narrow',
	'weights' => array('normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Aref Ruqaa' => array(
	'family'  => 'Aref Ruqaa',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('arabic', 'latin'),
	'gf'      => true,
),
'Arima Madurai' => array(
	'family'  => 'Arima Madurai',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext', 'tamil'),
	'gf'      => true,
),
'Arimo' => array(
	'family'  => 'Arimo',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('greek', 'vietnamese', 'greek-ext', 'cyrillic-ext', 'hebrew', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Arizonia' => array(
	'family'  => 'Arizonia',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Armata' => array(
	'family'  => 'Armata',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Arsenal' => array(
	'family'  => 'Arsenal',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('vietnamese', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Artifika' => array(
	'family'  => 'Artifika',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Arvo' => array(
	'family'  => 'Arvo',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Arya' => array(
	'family'  => 'Arya',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('devanagari', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Asap' => array(
	'family'  => 'Asap',
	'weights' => array('normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Asap Condensed' => array(
	'family'  => 'Asap Condensed',
	'weights' => array('normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Asar' => array(
	'family'  => 'Asar',
	'weights' => array('normal'),
	'subsets' => array('devanagari', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Asset' => array(
	'family'  => 'Asset',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Assistant' => array(
	'family'  => 'Assistant',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic'),
	'subsets' => array('hebrew', 'latin'),
	'gf'      => true,
),
'Astloch' => array(
	'family'  => 'Astloch',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Asul' => array(
	'family'  => 'Asul',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Athiti' => array(
	'family'  => 'Athiti',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('thai', 'vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Atma' => array(
	'family'  => 'Atma',
	'weights' => array('300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('bengali', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Atomic Age' => array(
	'family'  => 'Atomic Age',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Aubrey' => array(
	'family'  => 'Aubrey',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Audiowide' => array(
	'family'  => 'Audiowide',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Autour One' => array(
	'family'  => 'Autour One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Average' => array(
	'family'  => 'Average',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Average Sans' => array(
	'family'  => 'Average Sans',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Averia Gruesa Libre' => array(
	'family'  => 'Averia Gruesa Libre',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Averia Libre' => array(
	'family'  => 'Averia Libre',
	'weights' => array('300', '300 italic', 'normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Averia Sans Libre' => array(
	'family'  => 'Averia Sans Libre',
	'weights' => array('300', '300 italic', 'normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Averia Serif Libre' => array(
	'family'  => 'Averia Serif Libre',
	'weights' => array('300', '300 italic', 'normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'B612' => array(
	'family'  => 'B612',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'B612 Mono' => array(
	'family'  => 'B612 Mono',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Bad Script' => array(
	'family'  => 'Bad Script',
	'weights' => array('normal'),
	'subsets' => array('latin', 'cyrillic'),
	'gf'      => true,
),
'Bahiana' => array(
	'family'  => 'Bahiana',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Bahianita' => array(
	'family'  => 'Bahianita',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Bai Jamjuree' => array(
	'family'  => 'Bai Jamjuree',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('thai', 'vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Baloo' => array(
	'family'  => 'Baloo',
	'weights' => array('normal'),
	'subsets' => array('devanagari', 'vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Baloo Bhai' => array(
	'family'  => 'Baloo Bhai',
	'weights' => array('normal'),
	'subsets' => array('gujarati', 'vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Baloo Bhaijaan' => array(
	'family'  => 'Baloo Bhaijaan',
	'weights' => array('normal'),
	'subsets' => array('arabic', 'vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Baloo Bhaina' => array(
	'family'  => 'Baloo Bhaina',
	'weights' => array('normal'),
	'subsets' => array('oriya', 'vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Baloo Chettan' => array(
	'family'  => 'Baloo Chettan',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'malayalam', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Baloo Da' => array(
	'family'  => 'Baloo Da',
	'weights' => array('normal'),
	'subsets' => array('bengali', 'vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Baloo Paaji' => array(
	'family'  => 'Baloo Paaji',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext', 'gurmukhi'),
	'gf'      => true,
),
'Baloo Tamma' => array(
	'family'  => 'Baloo Tamma',
	'weights' => array('normal'),
	'subsets' => array('kannada', 'vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Baloo Tammudu' => array(
	'family'  => 'Baloo Tammudu',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'telugu', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Baloo Thambi' => array(
	'family'  => 'Baloo Thambi',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext', 'tamil'),
	'gf'      => true,
),
'Balthazar' => array(
	'family'  => 'Balthazar',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Bangers' => array(
	'family'  => 'Bangers',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Barlow' => array(
	'family'  => 'Barlow',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Barlow Condensed' => array(
	'family'  => 'Barlow Condensed',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Barlow Semi Condensed' => array(
	'family'  => 'Barlow Semi Condensed',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Barriecito' => array(
	'family'  => 'Barriecito',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Barrio' => array(
	'family'  => 'Barrio',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Basic' => array(
	'family'  => 'Basic',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Baskervville' => array(
	'family'  => 'Baskervville',
	'weights' => array('normal', 'italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Battambang' => array(
	'family'  => 'Battambang',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('khmer'),
	'gf'      => true,
),
'Baumans' => array(
	'family'  => 'Baumans',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Bayon' => array(
	'family'  => 'Bayon',
	'weights' => array('normal'),
	'subsets' => array('khmer'),
	'gf'      => true,
),
'Be Vietnam' => array(
	'family'  => 'Be Vietnam',
	'weights' => array('100', '100 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Bebas Neue' => array(
	'family'  => 'Bebas Neue',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Belgrano' => array(
	'family'  => 'Belgrano',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Bellefair' => array(
	'family'  => 'Bellefair',
	'weights' => array('normal'),
	'subsets' => array('hebrew', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Belleza' => array(
	'family'  => 'Belleza',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'BenchNine' => array(
	'family'  => 'BenchNine',
	'weights' => array('300', '300 italic', 'normal', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Bentham' => array(
	'family'  => 'Bentham',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Berkshire Swash' => array(
	'family'  => 'Berkshire Swash',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Beth Ellen' => array(
	'family'  => 'Beth Ellen',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Bevan' => array(
	'family'  => 'Bevan',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Big Shoulders Display' => array(
	'family'  => 'Big Shoulders Display',
	'weights' => array('100', '100 italic', '300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Big Shoulders Text' => array(
	'family'  => 'Big Shoulders Text',
	'weights' => array('100', '100 italic', '300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Bigelow Rules' => array(
	'family'  => 'Bigelow Rules',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Bigshot One' => array(
	'family'  => 'Bigshot One',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Bilbo' => array(
	'family'  => 'Bilbo',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Bilbo Swash Caps' => array(
	'family'  => 'Bilbo Swash Caps',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'BioRhyme' => array(
	'family'  => 'BioRhyme',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', 'bold', 'bold italic', '800', '800 italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'BioRhyme Expanded' => array(
	'family'  => 'BioRhyme Expanded',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', 'bold', 'bold italic', '800', '800 italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Biryani' => array(
	'family'  => 'Biryani',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('devanagari', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Bitter' => array(
	'family'  => 'Bitter',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Black And White Picture' => array(
	'family'  => 'Black And White Picture',
	'weights' => array('normal'),
	'subsets' => array('korean', 'latin'),
	'gf'      => true,
),
'Black Han Sans' => array(
	'family'  => 'Black Han Sans',
	'weights' => array('normal'),
	'subsets' => array('korean', 'latin'),
	'gf'      => true,
),
'Black Ops One' => array(
	'family'  => 'Black Ops One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Blinker' => array(
	'family'  => 'Blinker',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Bokor' => array(
	'family'  => 'Bokor',
	'weights' => array('normal'),
	'subsets' => array('khmer'),
	'gf'      => true,
),
'Bonbon' => array(
	'family'  => 'Bonbon',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Boogaloo' => array(
	'family'  => 'Boogaloo',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Bowlby One' => array(
	'family'  => 'Bowlby One',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Bowlby One SC' => array(
	'family'  => 'Bowlby One SC',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Brawler' => array(
	'family'  => 'Brawler',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Bree Serif' => array(
	'family'  => 'Bree Serif',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Bubblegum Sans' => array(
	'family'  => 'Bubblegum Sans',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Bubbler One' => array(
	'family'  => 'Bubbler One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Buda' => array(
	'family'  => 'Buda',
	'weights' => array('300', '300 italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Buenard' => array(
	'family'  => 'Buenard',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Bungee' => array(
	'family'  => 'Bungee',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Bungee Hairline' => array(
	'family'  => 'Bungee Hairline',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Bungee Inline' => array(
	'family'  => 'Bungee Inline',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Bungee Outline' => array(
	'family'  => 'Bungee Outline',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Bungee Shade' => array(
	'family'  => 'Bungee Shade',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Butcherman' => array(
	'family'  => 'Butcherman',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Butterfly Kids' => array(
	'family'  => 'Butterfly Kids',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Cabin' => array(
	'family'  => 'Cabin',
	'weights' => array('normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Cabin Condensed' => array(
	'family'  => 'Cabin Condensed',
	'weights' => array('normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Cabin Sketch' => array(
	'family'  => 'Cabin Sketch',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Caesar Dressing' => array(
	'family'  => 'Caesar Dressing',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Cagliostro' => array(
	'family'  => 'Cagliostro',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Cairo' => array(
	'family'  => 'Cairo',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', '600', '600 italic', 'bold', 'bold italic', '900', '900 italic'),
	'subsets' => array('arabic', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Calistoga' => array(
	'family'  => 'Calistoga',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Calligraffitti' => array(
	'family'  => 'Calligraffitti',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Cambay' => array(
	'family'  => 'Cambay',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('devanagari', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Cambo' => array(
	'family'  => 'Cambo',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Candal' => array(
	'family'  => 'Candal',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Cantarell' => array(
	'family'  => 'Cantarell',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Cantata One' => array(
	'family'  => 'Cantata One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Cantora One' => array(
	'family'  => 'Cantora One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Capriola' => array(
	'family'  => 'Capriola',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Cardo' => array(
	'family'  => 'Cardo',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('greek', 'greek-ext', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Carme' => array(
	'family'  => 'Carme',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Carrois Gothic' => array(
	'family'  => 'Carrois Gothic',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Carrois Gothic SC' => array(
	'family'  => 'Carrois Gothic SC',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Carter One' => array(
	'family'  => 'Carter One',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Catamaran' => array(
	'family'  => 'Catamaran',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('latin', 'latin-ext', 'tamil'),
	'gf'      => true,
),
'Caudex' => array(
	'family'  => 'Caudex',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('greek', 'greek-ext', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Caveat' => array(
	'family'  => 'Caveat',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Caveat Brush' => array(
	'family'  => 'Caveat Brush',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Cedarville Cursive' => array(
	'family'  => 'Cedarville Cursive',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Ceviche One' => array(
	'family'  => 'Ceviche One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Chakra Petch' => array(
	'family'  => 'Chakra Petch',
	'weights' => array('300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('thai', 'vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Changa' => array(
	'family'  => 'Changa',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic'),
	'subsets' => array('arabic', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Changa One' => array(
	'family'  => 'Changa One',
	'weights' => array('normal', 'italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Chango' => array(
	'family'  => 'Chango',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Charm' => array(
	'family'  => 'Charm',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('thai', 'vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Charmonman' => array(
	'family'  => 'Charmonman',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('thai', 'vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Chathura' => array(
	'family'  => 'Chathura',
	'weights' => array('100', '100 italic', '300', '300 italic', 'normal', 'bold', 'bold italic', '800', '800 italic'),
	'subsets' => array('telugu', 'latin'),
	'gf'      => true,
),
'Chau Philomene One' => array(
	'family'  => 'Chau Philomene One',
	'weights' => array('normal', 'italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Chela One' => array(
	'family'  => 'Chela One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Chelsea Market' => array(
	'family'  => 'Chelsea Market',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Chenla' => array(
	'family'  => 'Chenla',
	'weights' => array('normal'),
	'subsets' => array('khmer'),
	'gf'      => true,
),
'Cherry Cream Soda' => array(
	'family'  => 'Cherry Cream Soda',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Cherry Swash' => array(
	'family'  => 'Cherry Swash',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Chewy' => array(
	'family'  => 'Chewy',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Chicle' => array(
	'family'  => 'Chicle',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Chilanka' => array(
	'family'  => 'Chilanka',
	'weights' => array('normal'),
	'subsets' => array('malayalam', 'latin'),
	'gf'      => true,
),
'Chivo' => array(
	'family'  => 'Chivo',
	'weights' => array('300', '300 italic', 'normal', 'italic', 'bold', 'bold italic', '900', '900 italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Chonburi' => array(
	'family'  => 'Chonburi',
	'weights' => array('normal'),
	'subsets' => array('thai', 'vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Cinzel' => array(
	'family'  => 'Cinzel',
	'weights' => array('normal', 'bold', 'bold italic', '900', '900 italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Cinzel Decorative' => array(
	'family'  => 'Cinzel Decorative',
	'weights' => array('normal', 'bold', 'bold italic', '900', '900 italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Clicker Script' => array(
	'family'  => 'Clicker Script',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Coda' => array(
	'family'  => 'Coda',
	'weights' => array('normal', '800', '800 italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Coda Caption' => array(
	'family'  => 'Coda Caption',
	'weights' => array('800', '800 italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Codystar' => array(
	'family'  => 'Codystar',
	'weights' => array('300', '300 italic', 'normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Coiny' => array(
	'family'  => 'Coiny',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext', 'tamil'),
	'gf'      => true,
),
'Combo' => array(
	'family'  => 'Combo',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Comfortaa' => array(
	'family'  => 'Comfortaa',
	'weights' => array('300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('greek', 'vietnamese', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Coming Soon' => array(
	'family'  => 'Coming Soon',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Concert One' => array(
	'family'  => 'Concert One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Condiment' => array(
	'family'  => 'Condiment',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Content' => array(
	'family'  => 'Content',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('khmer'),
	'gf'      => true,
),
'Contrail One' => array(
	'family'  => 'Contrail One',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Convergence' => array(
	'family'  => 'Convergence',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Cookie' => array(
	'family'  => 'Cookie',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Copse' => array(
	'family'  => 'Copse',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Corben' => array(
	'family'  => 'Corben',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Cormorant' => array(
	'family'  => 'Cormorant',
	'weights' => array('300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('vietnamese', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Cormorant Garamond' => array(
	'family'  => 'Cormorant Garamond',
	'weights' => array('300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('vietnamese', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Cormorant Infant' => array(
	'family'  => 'Cormorant Infant',
	'weights' => array('300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('vietnamese', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Cormorant SC' => array(
	'family'  => 'Cormorant SC',
	'weights' => array('300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('vietnamese', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Cormorant Unicase' => array(
	'family'  => 'Cormorant Unicase',
	'weights' => array('300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('vietnamese', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Cormorant Upright' => array(
	'family'  => 'Cormorant Upright',
	'weights' => array('300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Courgette' => array(
	'family'  => 'Courgette',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Courier Prime' => array(
	'family'  => 'Courier Prime',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Cousine' => array(
	'family'  => 'Cousine',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('greek', 'vietnamese', 'greek-ext', 'cyrillic-ext', 'hebrew', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Coustard' => array(
	'family'  => 'Coustard',
	'weights' => array('normal', '900', '900 italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Covered By Your Grace' => array(
	'family'  => 'Covered By Your Grace',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Crafty Girls' => array(
	'family'  => 'Crafty Girls',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Creepster' => array(
	'family'  => 'Creepster',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Crete Round' => array(
	'family'  => 'Crete Round',
	'weights' => array('normal', 'italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Crimson Pro' => array(
	'family'  => 'Crimson Pro',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic', 'italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Crimson Text' => array(
	'family'  => 'Crimson Text',
	'weights' => array('normal', 'italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Croissant One' => array(
	'family'  => 'Croissant One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Crushed' => array(
	'family'  => 'Crushed',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Cuprum' => array(
	'family'  => 'Cuprum',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('vietnamese', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Cute Font' => array(
	'family'  => 'Cute Font',
	'weights' => array('normal'),
	'subsets' => array('korean', 'latin'),
	'gf'      => true,
),
'Cutive' => array(
	'family'  => 'Cutive',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Cutive Mono' => array(
	'family'  => 'Cutive Mono',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'DM Sans' => array(
	'family'  => 'DM Sans',
	'weights' => array('normal', 'italic', '500', '500 italic', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'DM Serif Display' => array(
	'family'  => 'DM Serif Display',
	'weights' => array('normal', 'italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'DM Serif Text' => array(
	'family'  => 'DM Serif Text',
	'weights' => array('normal', 'italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Damion' => array(
	'family'  => 'Damion',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Dancing Script' => array(
	'family'  => 'Dancing Script',
	'weights' => array('normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Dangrek' => array(
	'family'  => 'Dangrek',
	'weights' => array('normal'),
	'subsets' => array('khmer'),
	'gf'      => true,
),
'Darker Grotesque' => array(
	'family'  => 'Darker Grotesque',
	'weights' => array('300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'David Libre' => array(
	'family'  => 'David Libre',
	'weights' => array('normal', '500', '500 italic', 'bold', 'bold italic'),
	'subsets' => array('vietnamese', 'hebrew', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Dawning of a New Day' => array(
	'family'  => 'Dawning of a New Day',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Days One' => array(
	'family'  => 'Days One',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Dekko' => array(
	'family'  => 'Dekko',
	'weights' => array('normal'),
	'subsets' => array('devanagari', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Delius' => array(
	'family'  => 'Delius',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Delius Swash Caps' => array(
	'family'  => 'Delius Swash Caps',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Delius Unicase' => array(
	'family'  => 'Delius Unicase',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Della Respira' => array(
	'family'  => 'Della Respira',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Denk One' => array(
	'family'  => 'Denk One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Devonshire' => array(
	'family'  => 'Devonshire',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Dhurjati' => array(
	'family'  => 'Dhurjati',
	'weights' => array('normal'),
	'subsets' => array('telugu', 'latin'),
	'gf'      => true,
),
'Didact Gothic' => array(
	'family'  => 'Didact Gothic',
	'weights' => array('normal'),
	'subsets' => array('greek', 'greek-ext', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Diplomata' => array(
	'family'  => 'Diplomata',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Diplomata SC' => array(
	'family'  => 'Diplomata SC',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Do Hyeon' => array(
	'family'  => 'Do Hyeon',
	'weights' => array('normal'),
	'subsets' => array('korean', 'latin'),
	'gf'      => true,
),
'Dokdo' => array(
	'family'  => 'Dokdo',
	'weights' => array('normal'),
	'subsets' => array('korean', 'latin'),
	'gf'      => true,
),
'Domine' => array(
	'family'  => 'Domine',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Donegal One' => array(
	'family'  => 'Donegal One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Doppio One' => array(
	'family'  => 'Doppio One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Dorsa' => array(
	'family'  => 'Dorsa',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Dosis' => array(
	'family'  => 'Dosis',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Dr Sugiyama' => array(
	'family'  => 'Dr Sugiyama',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Duru Sans' => array(
	'family'  => 'Duru Sans',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Dynalight' => array(
	'family'  => 'Dynalight',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'EB Garamond' => array(
	'family'  => 'EB Garamond',
	'weights' => array('normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', 'italic'),
	'subsets' => array('greek', 'vietnamese', 'greek-ext', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Eagle Lake' => array(
	'family'  => 'Eagle Lake',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'East Sea Dokdo' => array(
	'family'  => 'East Sea Dokdo',
	'weights' => array('normal'),
	'subsets' => array('korean', 'latin'),
	'gf'      => true,
),
'Eater' => array(
	'family'  => 'Eater',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Economica' => array(
	'family'  => 'Economica',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Eczar' => array(
	'family'  => 'Eczar',
	'weights' => array('normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic'),
	'subsets' => array('devanagari', 'latin', 'latin-ext'),
	'gf'      => true,
),
'El Messiri' => array(
	'family'  => 'El Messiri',
	'weights' => array('normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('arabic', 'latin', 'cyrillic'),
	'gf'      => true,
),
'Electrolize' => array(
	'family'  => 'Electrolize',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Elsie' => array(
	'family'  => 'Elsie',
	'weights' => array('normal', '900', '900 italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Elsie Swash Caps' => array(
	'family'  => 'Elsie Swash Caps',
	'weights' => array('normal', '900', '900 italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Emblema One' => array(
	'family'  => 'Emblema One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Emilys Candy' => array(
	'family'  => 'Emilys Candy',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Encode Sans' => array(
	'family'  => 'Encode Sans',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Encode Sans Condensed' => array(
	'family'  => 'Encode Sans Condensed',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Encode Sans Expanded' => array(
	'family'  => 'Encode Sans Expanded',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Encode Sans Semi Condensed' => array(
	'family'  => 'Encode Sans Semi Condensed',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Encode Sans Semi Expanded' => array(
	'family'  => 'Encode Sans Semi Expanded',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Engagement' => array(
	'family'  => 'Engagement',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Englebert' => array(
	'family'  => 'Englebert',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Enriqueta' => array(
	'family'  => 'Enriqueta',
	'weights' => array('normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Erica One' => array(
	'family'  => 'Erica One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Esteban' => array(
	'family'  => 'Esteban',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Euphoria Script' => array(
	'family'  => 'Euphoria Script',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Ewert' => array(
	'family'  => 'Ewert',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Exo' => array(
	'family'  => 'Exo',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Exo 2' => array(
	'family'  => 'Exo 2',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('vietnamese', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Expletus Sans' => array(
	'family'  => 'Expletus Sans',
	'weights' => array('normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Fahkwang' => array(
	'family'  => 'Fahkwang',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('thai', 'vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Fanwood Text' => array(
	'family'  => 'Fanwood Text',
	'weights' => array('normal', 'italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Farro' => array(
	'family'  => 'Farro',
	'weights' => array('300', '300 italic', 'normal', '500', '500 italic', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Farsan' => array(
	'family'  => 'Farsan',
	'weights' => array('normal'),
	'subsets' => array('gujarati', 'vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Fascinate' => array(
	'family'  => 'Fascinate',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Fascinate Inline' => array(
	'family'  => 'Fascinate Inline',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Faster One' => array(
	'family'  => 'Faster One',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Fasthand' => array(
	'family'  => 'Fasthand',
	'weights' => array('normal'),
	'subsets' => array('khmer'),
	'gf'      => true,
),
'Fauna One' => array(
	'family'  => 'Fauna One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Faustina' => array(
	'family'  => 'Faustina',
	'weights' => array('normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', 'italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Federant' => array(
	'family'  => 'Federant',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Federo' => array(
	'family'  => 'Federo',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Felipa' => array(
	'family'  => 'Felipa',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Fenix' => array(
	'family'  => 'Fenix',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Finger Paint' => array(
	'family'  => 'Finger Paint',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Fira Code' => array(
	'family'  => 'Fira Code',
	'weights' => array('300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('greek', 'greek-ext', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Fira Mono' => array(
	'family'  => 'Fira Mono',
	'weights' => array('normal', '500', '500 italic', 'bold', 'bold italic'),
	'subsets' => array('greek', 'greek-ext', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Fira Sans' => array(
	'family'  => 'Fira Sans',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('greek', 'vietnamese', 'greek-ext', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Fira Sans Condensed' => array(
	'family'  => 'Fira Sans Condensed',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('greek', 'vietnamese', 'greek-ext', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Fira Sans Extra Condensed' => array(
	'family'  => 'Fira Sans Extra Condensed',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('greek', 'vietnamese', 'greek-ext', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Fjalla One' => array(
	'family'  => 'Fjalla One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Fjord One' => array(
	'family'  => 'Fjord One',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Flamenco' => array(
	'family'  => 'Flamenco',
	'weights' => array('300', '300 italic', 'normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Flavors' => array(
	'family'  => 'Flavors',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Fondamento' => array(
	'family'  => 'Fondamento',
	'weights' => array('normal', 'italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Fontdiner Swanky' => array(
	'family'  => 'Fontdiner Swanky',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Forum' => array(
	'family'  => 'Forum',
	'weights' => array('normal'),
	'subsets' => array('cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Francois One' => array(
	'family'  => 'Francois One',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Frank Ruhl Libre' => array(
	'family'  => 'Frank Ruhl Libre',
	'weights' => array('300', '300 italic', 'normal', '500', '500 italic', 'bold', 'bold italic', '900', '900 italic'),
	'subsets' => array('hebrew', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Freckle Face' => array(
	'family'  => 'Freckle Face',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Fredericka the Great' => array(
	'family'  => 'Fredericka the Great',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Fredoka One' => array(
	'family'  => 'Fredoka One',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Freehand' => array(
	'family'  => 'Freehand',
	'weights' => array('normal'),
	'subsets' => array('khmer'),
	'gf'      => true,
),
'Fresca' => array(
	'family'  => 'Fresca',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Frijole' => array(
	'family'  => 'Frijole',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Fruktur' => array(
	'family'  => 'Fruktur',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Fugaz One' => array(
	'family'  => 'Fugaz One',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'GFS Didot' => array(
	'family'  => 'GFS Didot',
	'weights' => array('normal'),
	'subsets' => array('greek'),
	'gf'      => true,
),
'GFS Neohellenic' => array(
	'family'  => 'GFS Neohellenic',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('greek'),
	'gf'      => true,
),
'Gabriela' => array(
	'family'  => 'Gabriela',
	'weights' => array('normal'),
	'subsets' => array('cyrillic-ext', 'latin', 'cyrillic'),
	'gf'      => true,
),
'Gaegu' => array(
	'family'  => 'Gaegu',
	'weights' => array('300', '300 italic', 'normal', 'bold', 'bold italic'),
	'subsets' => array('korean', 'latin'),
	'gf'      => true,
),
'Gafata' => array(
	'family'  => 'Gafata',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Galada' => array(
	'family'  => 'Galada',
	'weights' => array('normal'),
	'subsets' => array('bengali', 'latin'),
	'gf'      => true,
),
'Galdeano' => array(
	'family'  => 'Galdeano',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Galindo' => array(
	'family'  => 'Galindo',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Gamja Flower' => array(
	'family'  => 'Gamja Flower',
	'weights' => array('normal'),
	'subsets' => array('korean', 'latin'),
	'gf'      => true,
),
'Gayathri' => array(
	'family'  => 'Gayathri',
	'weights' => array('100', '100 italic', 'normal', 'bold', 'bold italic'),
	'subsets' => array('malayalam', 'latin'),
	'gf'      => true,
),
'Gelasio' => array(
	'family'  => 'Gelasio',
	'weights' => array('normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Gentium Basic' => array(
	'family'  => 'Gentium Basic',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Gentium Book Basic' => array(
	'family'  => 'Gentium Book Basic',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Geo' => array(
	'family'  => 'Geo',
	'weights' => array('normal', 'italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Geostar' => array(
	'family'  => 'Geostar',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Geostar Fill' => array(
	'family'  => 'Geostar Fill',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Germania One' => array(
	'family'  => 'Germania One',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Gidugu' => array(
	'family'  => 'Gidugu',
	'weights' => array('normal'),
	'subsets' => array('telugu', 'latin'),
	'gf'      => true,
),
'Gilda Display' => array(
	'family'  => 'Gilda Display',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Girassol' => array(
	'family'  => 'Girassol',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Give You Glory' => array(
	'family'  => 'Give You Glory',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Glass Antiqua' => array(
	'family'  => 'Glass Antiqua',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Glegoo' => array(
	'family'  => 'Glegoo',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('devanagari', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Gloria Hallelujah' => array(
	'family'  => 'Gloria Hallelujah',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Goblin One' => array(
	'family'  => 'Goblin One',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Gochi Hand' => array(
	'family'  => 'Gochi Hand',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Gorditas' => array(
	'family'  => 'Gorditas',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Gothic A1' => array(
	'family'  => 'Gothic A1',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('korean', 'latin'),
	'gf'      => true,
),
'Goudy Bookletter 1911' => array(
	'family'  => 'Goudy Bookletter 1911',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Graduate' => array(
	'family'  => 'Graduate',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Grand Hotel' => array(
	'family'  => 'Grand Hotel',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Gravitas One' => array(
	'family'  => 'Gravitas One',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Great Vibes' => array(
	'family'  => 'Great Vibes',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Grenze' => array(
	'family'  => 'Grenze',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Griffy' => array(
	'family'  => 'Griffy',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Gruppo' => array(
	'family'  => 'Gruppo',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Gudea' => array(
	'family'  => 'Gudea',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Gugi' => array(
	'family'  => 'Gugi',
	'weights' => array('normal'),
	'subsets' => array('korean', 'latin'),
	'gf'      => true,
),
'Gupter' => array(
	'family'  => 'Gupter',
	'weights' => array('normal', '500', '500 italic', 'bold', 'bold italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Gurajada' => array(
	'family'  => 'Gurajada',
	'weights' => array('normal'),
	'subsets' => array('telugu', 'latin'),
	'gf'      => true,
),
'Habibi' => array(
	'family'  => 'Habibi',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Halant' => array(
	'family'  => 'Halant',
	'weights' => array('300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('devanagari', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Hammersmith One' => array(
	'family'  => 'Hammersmith One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Hanalei' => array(
	'family'  => 'Hanalei',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Hanalei Fill' => array(
	'family'  => 'Hanalei Fill',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Handlee' => array(
	'family'  => 'Handlee',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Hanuman' => array(
	'family'  => 'Hanuman',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('khmer'),
	'gf'      => true,
),
'Happy Monkey' => array(
	'family'  => 'Happy Monkey',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Harmattan' => array(
	'family'  => 'Harmattan',
	'weights' => array('normal'),
	'subsets' => array('arabic', 'latin'),
	'gf'      => true,
),
'Headland One' => array(
	'family'  => 'Headland One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Heebo' => array(
	'family'  => 'Heebo',
	'weights' => array('100', '100 italic', '300', '300 italic', 'normal', '500', '500 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('hebrew', 'latin'),
	'gf'      => true,
),
'Henny Penny' => array(
	'family'  => 'Henny Penny',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Hepta Slab' => array(
	'family'  => 'Hepta Slab',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Herr Von Muellerhoff' => array(
	'family'  => 'Herr Von Muellerhoff',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Hi Melody' => array(
	'family'  => 'Hi Melody',
	'weights' => array('normal'),
	'subsets' => array('korean', 'latin'),
	'gf'      => true,
),
'Hind' => array(
	'family'  => 'Hind',
	'weights' => array('300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('devanagari', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Hind Guntur' => array(
	'family'  => 'Hind Guntur',
	'weights' => array('300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('telugu', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Hind Madurai' => array(
	'family'  => 'Hind Madurai',
	'weights' => array('300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext', 'tamil'),
	'gf'      => true,
),
'Hind Siliguri' => array(
	'family'  => 'Hind Siliguri',
	'weights' => array('300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('bengali', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Hind Vadodara' => array(
	'family'  => 'Hind Vadodara',
	'weights' => array('300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('gujarati', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Holtwood One SC' => array(
	'family'  => 'Holtwood One SC',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Homemade Apple' => array(
	'family'  => 'Homemade Apple',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Homenaje' => array(
	'family'  => 'Homenaje',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'IBM Plex Mono' => array(
	'family'  => 'IBM Plex Mono',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('vietnamese', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'IBM Plex Sans' => array(
	'family'  => 'IBM Plex Sans',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('greek', 'vietnamese', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'IBM Plex Sans Condensed' => array(
	'family'  => 'IBM Plex Sans Condensed',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'IBM Plex Serif' => array(
	'family'  => 'IBM Plex Serif',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('vietnamese', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'IM Fell DW Pica' => array(
	'family'  => 'IM Fell DW Pica',
	'weights' => array('normal', 'italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'IM Fell DW Pica SC' => array(
	'family'  => 'IM Fell DW Pica SC',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'IM Fell Double Pica' => array(
	'family'  => 'IM Fell Double Pica',
	'weights' => array('normal', 'italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'IM Fell Double Pica SC' => array(
	'family'  => 'IM Fell Double Pica SC',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'IM Fell English' => array(
	'family'  => 'IM Fell English',
	'weights' => array('normal', 'italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'IM Fell English SC' => array(
	'family'  => 'IM Fell English SC',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'IM Fell French Canon' => array(
	'family'  => 'IM Fell French Canon',
	'weights' => array('normal', 'italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'IM Fell French Canon SC' => array(
	'family'  => 'IM Fell French Canon SC',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'IM Fell Great Primer' => array(
	'family'  => 'IM Fell Great Primer',
	'weights' => array('normal', 'italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'IM Fell Great Primer SC' => array(
	'family'  => 'IM Fell Great Primer SC',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Ibarra Real Nova' => array(
	'family'  => 'Ibarra Real Nova',
	'weights' => array('normal', 'italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Iceberg' => array(
	'family'  => 'Iceberg',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Iceland' => array(
	'family'  => 'Iceland',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Imprima' => array(
	'family'  => 'Imprima',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Inconsolata' => array(
	'family'  => 'Inconsolata',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Inder' => array(
	'family'  => 'Inder',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Indie Flower' => array(
	'family'  => 'Indie Flower',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Inika' => array(
	'family'  => 'Inika',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Inknut Antiqua' => array(
	'family'  => 'Inknut Antiqua',
	'weights' => array('300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('devanagari', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Inria Serif' => array(
	'family'  => 'Inria Serif',
	'weights' => array('300', '300 italic', 'normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Irish Grover' => array(
	'family'  => 'Irish Grover',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Istok Web' => array(
	'family'  => 'Istok Web',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Italiana' => array(
	'family'  => 'Italiana',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Italianno' => array(
	'family'  => 'Italianno',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Itim' => array(
	'family'  => 'Itim',
	'weights' => array('normal'),
	'subsets' => array('thai', 'vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Jacques Francois' => array(
	'family'  => 'Jacques Francois',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Jacques Francois Shadow' => array(
	'family'  => 'Jacques Francois Shadow',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Jaldi' => array(
	'family'  => 'Jaldi',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('devanagari', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Jim Nightshade' => array(
	'family'  => 'Jim Nightshade',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Jockey One' => array(
	'family'  => 'Jockey One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Jolly Lodger' => array(
	'family'  => 'Jolly Lodger',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Jomhuria' => array(
	'family'  => 'Jomhuria',
	'weights' => array('normal'),
	'subsets' => array('arabic', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Jomolhari' => array(
	'family'  => 'Jomolhari',
	'weights' => array('normal'),
	'subsets' => array('tibetan', 'latin'),
	'gf'      => true,
),
'Josefin Sans' => array(
	'family'  => 'Josefin Sans',
	'weights' => array('100', '100 italic', '300', '300 italic', 'normal', 'italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Josefin Slab' => array(
	'family'  => 'Josefin Slab',
	'weights' => array('100', '100 italic', '300', '300 italic', 'normal', 'italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Joti One' => array(
	'family'  => 'Joti One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Jua' => array(
	'family'  => 'Jua',
	'weights' => array('normal'),
	'subsets' => array('korean', 'latin'),
	'gf'      => true,
),
'Judson' => array(
	'family'  => 'Judson',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Julee' => array(
	'family'  => 'Julee',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Julius Sans One' => array(
	'family'  => 'Julius Sans One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Junge' => array(
	'family'  => 'Junge',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Jura' => array(
	'family'  => 'Jura',
	'weights' => array('300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('greek', 'vietnamese', 'greek-ext', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Just Another Hand' => array(
	'family'  => 'Just Another Hand',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Just Me Again Down Here' => array(
	'family'  => 'Just Me Again Down Here',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'K2D' => array(
	'family'  => 'K2D',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic'),
	'subsets' => array('thai', 'vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Kadwa' => array(
	'family'  => 'Kadwa',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('devanagari', 'latin'),
	'gf'      => true,
),
'Kalam' => array(
	'family'  => 'Kalam',
	'weights' => array('300', '300 italic', 'normal', 'bold', 'bold italic'),
	'subsets' => array('devanagari', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Kameron' => array(
	'family'  => 'Kameron',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Kanit' => array(
	'family'  => 'Kanit',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('thai', 'vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Kantumruy' => array(
	'family'  => 'Kantumruy',
	'weights' => array('300', '300 italic', 'normal', 'bold', 'bold italic'),
	'subsets' => array('khmer'),
	'gf'      => true,
),
'Karla' => array(
	'family'  => 'Karla',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Karma' => array(
	'family'  => 'Karma',
	'weights' => array('300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('devanagari', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Katibeh' => array(
	'family'  => 'Katibeh',
	'weights' => array('normal'),
	'subsets' => array('arabic', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Kaushan Script' => array(
	'family'  => 'Kaushan Script',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Kavivanar' => array(
	'family'  => 'Kavivanar',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext', 'tamil'),
	'gf'      => true,
),
'Kavoon' => array(
	'family'  => 'Kavoon',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Kdam Thmor' => array(
	'family'  => 'Kdam Thmor',
	'weights' => array('normal'),
	'subsets' => array('khmer'),
	'gf'      => true,
),
'Keania One' => array(
	'family'  => 'Keania One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Kelly Slab' => array(
	'family'  => 'Kelly Slab',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Kenia' => array(
	'family'  => 'Kenia',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Khand' => array(
	'family'  => 'Khand',
	'weights' => array('300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('devanagari', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Khmer' => array(
	'family'  => 'Khmer',
	'weights' => array('normal'),
	'subsets' => array('khmer'),
	'gf'      => true,
),
'Khula' => array(
	'family'  => 'Khula',
	'weights' => array('300', '300 italic', 'normal', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic'),
	'subsets' => array('devanagari', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Kirang Haerang' => array(
	'family'  => 'Kirang Haerang',
	'weights' => array('normal'),
	'subsets' => array('korean', 'latin'),
	'gf'      => true,
),
'Kite One' => array(
	'family'  => 'Kite One',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Knewave' => array(
	'family'  => 'Knewave',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'KoHo' => array(
	'family'  => 'KoHo',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('thai', 'vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Kodchasan' => array(
	'family'  => 'Kodchasan',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('thai', 'vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Kosugi' => array(
	'family'  => 'Kosugi',
	'weights' => array('normal'),
	'subsets' => array('japanese', 'latin', 'cyrillic'),
	'gf'      => true,
),
'Kosugi Maru' => array(
	'family'  => 'Kosugi Maru',
	'weights' => array('normal'),
	'subsets' => array('japanese', 'latin', 'cyrillic'),
	'gf'      => true,
),
'Kotta One' => array(
	'family'  => 'Kotta One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Koulen' => array(
	'family'  => 'Koulen',
	'weights' => array('normal'),
	'subsets' => array('khmer'),
	'gf'      => true,
),
'Kranky' => array(
	'family'  => 'Kranky',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Kreon' => array(
	'family'  => 'Kreon',
	'weights' => array('300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Kristi' => array(
	'family'  => 'Kristi',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Krona One' => array(
	'family'  => 'Krona One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Krub' => array(
	'family'  => 'Krub',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('thai', 'vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Kulim Park' => array(
	'family'  => 'Kulim Park',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', 'italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Kumar One' => array(
	'family'  => 'Kumar One',
	'weights' => array('normal'),
	'subsets' => array('gujarati', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Kumar One Outline' => array(
	'family'  => 'Kumar One Outline',
	'weights' => array('normal'),
	'subsets' => array('gujarati', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Kurale' => array(
	'family'  => 'Kurale',
	'weights' => array('normal'),
	'subsets' => array('devanagari', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'La Belle Aurore' => array(
	'family'  => 'La Belle Aurore',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Lacquer' => array(
	'family'  => 'Lacquer',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Laila' => array(
	'family'  => 'Laila',
	'weights' => array('300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('devanagari', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Lakki Reddy' => array(
	'family'  => 'Lakki Reddy',
	'weights' => array('normal'),
	'subsets' => array('telugu', 'latin'),
	'gf'      => true,
),
'Lalezar' => array(
	'family'  => 'Lalezar',
	'weights' => array('normal'),
	'subsets' => array('arabic', 'vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Lancelot' => array(
	'family'  => 'Lancelot',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Lateef' => array(
	'family'  => 'Lateef',
	'weights' => array('normal'),
	'subsets' => array('arabic', 'latin'),
	'gf'      => true,
),
'Lato' => array(
	'family'  => 'Lato',
	'weights' => array('100', '100 italic', '300', '300 italic', 'normal', 'italic', 'bold', 'bold italic', '900', '900 italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'League Script' => array(
	'family'  => 'League Script',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Leckerli One' => array(
	'family'  => 'Leckerli One',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Ledger' => array(
	'family'  => 'Ledger',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Lekton' => array(
	'family'  => 'Lekton',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Lemon' => array(
	'family'  => 'Lemon',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Lemonada' => array(
	'family'  => 'Lemonada',
	'weights' => array('300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('arabic', 'vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Lexend Deca' => array(
	'family'  => 'Lexend Deca',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Lexend Exa' => array(
	'family'  => 'Lexend Exa',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Lexend Giga' => array(
	'family'  => 'Lexend Giga',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Lexend Mega' => array(
	'family'  => 'Lexend Mega',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Lexend Peta' => array(
	'family'  => 'Lexend Peta',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Lexend Tera' => array(
	'family'  => 'Lexend Tera',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Lexend Zetta' => array(
	'family'  => 'Lexend Zetta',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Libre Barcode 128' => array(
	'family'  => 'Libre Barcode 128',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Libre Barcode 128 Text' => array(
	'family'  => 'Libre Barcode 128 Text',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Libre Barcode 39' => array(
	'family'  => 'Libre Barcode 39',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Libre Barcode 39 Extended' => array(
	'family'  => 'Libre Barcode 39 Extended',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Libre Barcode 39 Extended Text' => array(
	'family'  => 'Libre Barcode 39 Extended Text',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Libre Barcode 39 Text' => array(
	'family'  => 'Libre Barcode 39 Text',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Libre Baskerville' => array(
	'family'  => 'Libre Baskerville',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Libre Caslon Display' => array(
	'family'  => 'Libre Caslon Display',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Libre Caslon Text' => array(
	'family'  => 'Libre Caslon Text',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Libre Franklin' => array(
	'family'  => 'Libre Franklin',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Life Savers' => array(
	'family'  => 'Life Savers',
	'weights' => array('normal', 'bold', 'bold italic', '800', '800 italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Lilita One' => array(
	'family'  => 'Lilita One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Lily Script One' => array(
	'family'  => 'Lily Script One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Limelight' => array(
	'family'  => 'Limelight',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Linden Hill' => array(
	'family'  => 'Linden Hill',
	'weights' => array('normal', 'italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Literata' => array(
	'family'  => 'Literata',
	'weights' => array('normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', 'italic'),
	'subsets' => array('greek', 'vietnamese', 'greek-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Liu Jian Mao Cao' => array(
	'family'  => 'Liu Jian Mao Cao',
	'weights' => array('normal'),
	'subsets' => array('latin', 'chinese-simplified'),
	'gf'      => true,
),
'Livvic' => array(
	'family'  => 'Livvic',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '900', '900 italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Lobster' => array(
	'family'  => 'Lobster',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Lobster Two' => array(
	'family'  => 'Lobster Two',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Londrina Outline' => array(
	'family'  => 'Londrina Outline',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Londrina Shadow' => array(
	'family'  => 'Londrina Shadow',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Londrina Sketch' => array(
	'family'  => 'Londrina Sketch',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Londrina Solid' => array(
	'family'  => 'Londrina Solid',
	'weights' => array('100', '100 italic', '300', '300 italic', 'normal', '900', '900 italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Long Cang' => array(
	'family'  => 'Long Cang',
	'weights' => array('normal'),
	'subsets' => array('latin', 'chinese-simplified'),
	'gf'      => true,
),
'Lora' => array(
	'family'  => 'Lora',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('vietnamese', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Love Ya Like A Sister' => array(
	'family'  => 'Love Ya Like A Sister',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Loved by the King' => array(
	'family'  => 'Loved by the King',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Lovers Quarrel' => array(
	'family'  => 'Lovers Quarrel',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Luckiest Guy' => array(
	'family'  => 'Luckiest Guy',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Lusitana' => array(
	'family'  => 'Lusitana',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Lustria' => array(
	'family'  => 'Lustria',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'M PLUS 1p' => array(
	'family'  => 'M PLUS 1p',
	'weights' => array('100', '100 italic', '300', '300 italic', 'normal', '500', '500 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('japanese', 'greek', 'vietnamese', 'greek-ext', 'cyrillic-ext', 'hebrew', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'M PLUS Rounded 1c' => array(
	'family'  => 'M PLUS Rounded 1c',
	'weights' => array('100', '100 italic', '300', '300 italic', 'normal', '500', '500 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('japanese', 'greek', 'vietnamese', 'greek-ext', 'cyrillic-ext', 'hebrew', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Ma Shan Zheng' => array(
	'family'  => 'Ma Shan Zheng',
	'weights' => array('normal'),
	'subsets' => array('latin', 'chinese-simplified'),
	'gf'      => true,
),
'Macondo' => array(
	'family'  => 'Macondo',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Macondo Swash Caps' => array(
	'family'  => 'Macondo Swash Caps',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Mada' => array(
	'family'  => 'Mada',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '900', '900 italic'),
	'subsets' => array('arabic', 'latin'),
	'gf'      => true,
),
'Magra' => array(
	'family'  => 'Magra',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Maiden Orange' => array(
	'family'  => 'Maiden Orange',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Maitree' => array(
	'family'  => 'Maitree',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('thai', 'vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Major Mono Display' => array(
	'family'  => 'Major Mono Display',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Mako' => array(
	'family'  => 'Mako',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Mali' => array(
	'family'  => 'Mali',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('thai', 'vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Mallanna' => array(
	'family'  => 'Mallanna',
	'weights' => array('normal'),
	'subsets' => array('telugu', 'latin'),
	'gf'      => true,
),
'Mandali' => array(
	'family'  => 'Mandali',
	'weights' => array('normal'),
	'subsets' => array('telugu', 'latin'),
	'gf'      => true,
),
'Manjari' => array(
	'family'  => 'Manjari',
	'weights' => array('100', '100 italic', 'normal', 'bold', 'bold italic'),
	'subsets' => array('malayalam', 'latin'),
	'gf'      => true,
),
'Mansalva' => array(
	'family'  => 'Mansalva',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Manuale' => array(
	'family'  => 'Manuale',
	'weights' => array('normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', 'italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Marcellus' => array(
	'family'  => 'Marcellus',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Marcellus SC' => array(
	'family'  => 'Marcellus SC',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Marck Script' => array(
	'family'  => 'Marck Script',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Margarine' => array(
	'family'  => 'Margarine',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Markazi Text' => array(
	'family'  => 'Markazi Text',
	'weights' => array('normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('arabic', 'vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Marko One' => array(
	'family'  => 'Marko One',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Marmelad' => array(
	'family'  => 'Marmelad',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Martel' => array(
	'family'  => 'Martel',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('devanagari', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Martel Sans' => array(
	'family'  => 'Martel Sans',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('devanagari', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Marvel' => array(
	'family'  => 'Marvel',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Mate' => array(
	'family'  => 'Mate',
	'weights' => array('normal', 'italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Mate SC' => array(
	'family'  => 'Mate SC',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Maven Pro' => array(
	'family'  => 'Maven Pro',
	'weights' => array('normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'McLaren' => array(
	'family'  => 'McLaren',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Meddon' => array(
	'family'  => 'Meddon',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'MedievalSharp' => array(
	'family'  => 'MedievalSharp',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Medula One' => array(
	'family'  => 'Medula One',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Meera Inimai' => array(
	'family'  => 'Meera Inimai',
	'weights' => array('normal'),
	'subsets' => array('latin', 'tamil'),
	'gf'      => true,
),
'Megrim' => array(
	'family'  => 'Megrim',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Meie Script' => array(
	'family'  => 'Meie Script',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Merienda' => array(
	'family'  => 'Merienda',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Merienda One' => array(
	'family'  => 'Merienda One',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Merriweather' => array(
	'family'  => 'Merriweather',
	'weights' => array('300', '300 italic', 'normal', 'italic', 'bold', 'bold italic', '900', '900 italic'),
	'subsets' => array('vietnamese', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Merriweather Sans' => array(
	'family'  => 'Merriweather Sans',
	'weights' => array('300', '300 italic', 'normal', 'italic', 'bold', 'bold italic', '800', '800 italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Metal' => array(
	'family'  => 'Metal',
	'weights' => array('normal'),
	'subsets' => array('khmer'),
	'gf'      => true,
),
'Metal Mania' => array(
	'family'  => 'Metal Mania',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Metamorphous' => array(
	'family'  => 'Metamorphous',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Metrophobic' => array(
	'family'  => 'Metrophobic',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Michroma' => array(
	'family'  => 'Michroma',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Milonga' => array(
	'family'  => 'Milonga',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Miltonian' => array(
	'family'  => 'Miltonian',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Miltonian Tattoo' => array(
	'family'  => 'Miltonian Tattoo',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Mina' => array(
	'family'  => 'Mina',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('bengali', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Miniver' => array(
	'family'  => 'Miniver',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Miriam Libre' => array(
	'family'  => 'Miriam Libre',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('hebrew', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Mirza' => array(
	'family'  => 'Mirza',
	'weights' => array('normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('arabic', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Miss Fajardose' => array(
	'family'  => 'Miss Fajardose',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Mitr' => array(
	'family'  => 'Mitr',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('thai', 'vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Modak' => array(
	'family'  => 'Modak',
	'weights' => array('normal'),
	'subsets' => array('devanagari', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Modern Antiqua' => array(
	'family'  => 'Modern Antiqua',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Mogra' => array(
	'family'  => 'Mogra',
	'weights' => array('normal'),
	'subsets' => array('gujarati', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Molengo' => array(
	'family'  => 'Molengo',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Molle' => array(
	'family'  => 'Molle',
	'weights' => array('italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Monda' => array(
	'family'  => 'Monda',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Monofett' => array(
	'family'  => 'Monofett',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Monoton' => array(
	'family'  => 'Monoton',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Monsieur La Doulaise' => array(
	'family'  => 'Monsieur La Doulaise',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Montaga' => array(
	'family'  => 'Montaga',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Montez' => array(
	'family'  => 'Montez',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Montserrat' => array(
	'family'  => 'Montserrat',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('vietnamese', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Montserrat Alternates' => array(
	'family'  => 'Montserrat Alternates',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('vietnamese', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Montserrat Subrayada' => array(
	'family'  => 'Montserrat Subrayada',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Moul' => array(
	'family'  => 'Moul',
	'weights' => array('normal'),
	'subsets' => array('khmer'),
	'gf'      => true,
),
'Moulpali' => array(
	'family'  => 'Moulpali',
	'weights' => array('normal'),
	'subsets' => array('khmer'),
	'gf'      => true,
),
'Mountains of Christmas' => array(
	'family'  => 'Mountains of Christmas',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Mouse Memoirs' => array(
	'family'  => 'Mouse Memoirs',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Mr Bedfort' => array(
	'family'  => 'Mr Bedfort',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Mr Dafoe' => array(
	'family'  => 'Mr Dafoe',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Mr De Haviland' => array(
	'family'  => 'Mr De Haviland',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Mrs Saint Delafield' => array(
	'family'  => 'Mrs Saint Delafield',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Mrs Sheppards' => array(
	'family'  => 'Mrs Sheppards',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Mukta' => array(
	'family'  => 'Mukta',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic'),
	'subsets' => array('devanagari', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Mukta Mahee' => array(
	'family'  => 'Mukta Mahee',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic'),
	'subsets' => array('latin', 'latin-ext', 'gurmukhi'),
	'gf'      => true,
),
'Mukta Malar' => array(
	'family'  => 'Mukta Malar',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic'),
	'subsets' => array('latin', 'latin-ext', 'tamil'),
	'gf'      => true,
),
'Mukta Vaani' => array(
	'family'  => 'Mukta Vaani',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic'),
	'subsets' => array('gujarati', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Muli' => array(
	'family'  => 'Muli',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic', 'italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Mystery Quest' => array(
	'family'  => 'Mystery Quest',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'NTR' => array(
	'family'  => 'NTR',
	'weights' => array('normal'),
	'subsets' => array('telugu', 'latin'),
	'gf'      => true,
),
'Nanum Brush Script' => array(
	'family'  => 'Nanum Brush Script',
	'weights' => array('normal'),
	'subsets' => array('korean', 'latin'),
	'gf'      => true,
),
'Nanum Gothic' => array(
	'family'  => 'Nanum Gothic',
	'weights' => array('normal', 'bold', 'bold italic', '800', '800 italic'),
	'subsets' => array('korean', 'latin'),
	'gf'      => true,
),
'Nanum Gothic Coding' => array(
	'family'  => 'Nanum Gothic Coding',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('korean', 'latin'),
	'gf'      => true,
),
'Nanum Myeongjo' => array(
	'family'  => 'Nanum Myeongjo',
	'weights' => array('normal', 'bold', 'bold italic', '800', '800 italic'),
	'subsets' => array('korean', 'latin'),
	'gf'      => true,
),
'Nanum Pen Script' => array(
	'family'  => 'Nanum Pen Script',
	'weights' => array('normal'),
	'subsets' => array('korean', 'latin'),
	'gf'      => true,
),
'Neucha' => array(
	'family'  => 'Neucha',
	'weights' => array('normal'),
	'subsets' => array('latin', 'cyrillic'),
	'gf'      => true,
),
'Neuton' => array(
	'family'  => 'Neuton',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', 'italic', 'bold', 'bold italic', '800', '800 italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'New Rocker' => array(
	'family'  => 'New Rocker',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'News Cycle' => array(
	'family'  => 'News Cycle',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Niconne' => array(
	'family'  => 'Niconne',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Niramit' => array(
	'family'  => 'Niramit',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('thai', 'vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Nixie One' => array(
	'family'  => 'Nixie One',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Nobile' => array(
	'family'  => 'Nobile',
	'weights' => array('normal', 'italic', '500', '500 italic', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Nokora' => array(
	'family'  => 'Nokora',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('khmer'),
	'gf'      => true,
),
'Norican' => array(
	'family'  => 'Norican',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Nosifer' => array(
	'family'  => 'Nosifer',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Notable' => array(
	'family'  => 'Notable',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Nothing You Could Do' => array(
	'family'  => 'Nothing You Could Do',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Noticia Text' => array(
	'family'  => 'Noticia Text',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Noto Sans' => array(
	'family'  => 'Noto Sans',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('devanagari', 'greek', 'vietnamese', 'greek-ext', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Noto Sans HK' => array(
	'family'  => 'Noto Sans HK',
	'weights' => array('100', '100 italic', '300', '300 italic', 'normal', '500', '500 italic', 'bold', 'bold italic', '900', '900 italic'),
	'subsets' => array('chinese-hongkong', 'latin'),
	'gf'      => true,
),
'Noto Sans JP' => array(
	'family'  => 'Noto Sans JP',
	'weights' => array('100', '100 italic', '300', '300 italic', 'normal', '500', '500 italic', 'bold', 'bold italic', '900', '900 italic'),
	'subsets' => array('japanese', 'latin'),
	'gf'      => true,
),
'Noto Sans KR' => array(
	'family'  => 'Noto Sans KR',
	'weights' => array('100', '100 italic', '300', '300 italic', 'normal', '500', '500 italic', 'bold', 'bold italic', '900', '900 italic'),
	'subsets' => array('korean', 'latin'),
	'gf'      => true,
),
'Noto Sans SC' => array(
	'family'  => 'Noto Sans SC',
	'weights' => array('100', '100 italic', '300', '300 italic', 'normal', '500', '500 italic', 'bold', 'bold italic', '900', '900 italic'),
	'subsets' => array('vietnamese', 'latin', 'chinese-simplified', 'cyrillic'),
	'gf'      => true,
),
'Noto Sans TC' => array(
	'family'  => 'Noto Sans TC',
	'weights' => array('100', '100 italic', '300', '300 italic', 'normal', '500', '500 italic', 'bold', 'bold italic', '900', '900 italic'),
	'subsets' => array('chinese-traditional', 'latin'),
	'gf'      => true,
),
'Noto Serif' => array(
	'family'  => 'Noto Serif',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('greek', 'vietnamese', 'greek-ext', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Noto Serif JP' => array(
	'family'  => 'Noto Serif JP',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '900', '900 italic'),
	'subsets' => array('japanese', 'latin'),
	'gf'      => true,
),
'Noto Serif KR' => array(
	'family'  => 'Noto Serif KR',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '900', '900 italic'),
	'subsets' => array('korean', 'latin'),
	'gf'      => true,
),
'Noto Serif SC' => array(
	'family'  => 'Noto Serif SC',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '900', '900 italic'),
	'subsets' => array('vietnamese', 'latin', 'chinese-simplified', 'cyrillic'),
	'gf'      => true,
),
'Noto Serif TC' => array(
	'family'  => 'Noto Serif TC',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '900', '900 italic'),
	'subsets' => array('vietnamese', 'chinese-traditional', 'latin', 'cyrillic'),
	'gf'      => true,
),
'Nova Cut' => array(
	'family'  => 'Nova Cut',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Nova Flat' => array(
	'family'  => 'Nova Flat',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Nova Mono' => array(
	'family'  => 'Nova Mono',
	'weights' => array('normal'),
	'subsets' => array('greek', 'latin'),
	'gf'      => true,
),
'Nova Oval' => array(
	'family'  => 'Nova Oval',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Nova Round' => array(
	'family'  => 'Nova Round',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Nova Script' => array(
	'family'  => 'Nova Script',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Nova Slim' => array(
	'family'  => 'Nova Slim',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Nova Square' => array(
	'family'  => 'Nova Square',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Numans' => array(
	'family'  => 'Numans',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Nunito' => array(
	'family'  => 'Nunito',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', 'italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('vietnamese', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Nunito Sans' => array(
	'family'  => 'Nunito Sans',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', 'italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Odibee Sans' => array(
	'family'  => 'Odibee Sans',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Odor Mean Chey' => array(
	'family'  => 'Odor Mean Chey',
	'weights' => array('normal'),
	'subsets' => array('khmer'),
	'gf'      => true,
),
'Offside' => array(
	'family'  => 'Offside',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Old Standard TT' => array(
	'family'  => 'Old Standard TT',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('vietnamese', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Oldenburg' => array(
	'family'  => 'Oldenburg',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Oleo Script' => array(
	'family'  => 'Oleo Script',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Oleo Script Swash Caps' => array(
	'family'  => 'Oleo Script Swash Caps',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Open Sans' => array(
	'family'  => 'Open Sans',
	'weights' => array('300', '300 italic', 'normal', 'italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic'),
	'subsets' => array('greek', 'vietnamese', 'greek-ext', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Open Sans Condensed' => array(
	'family'  => 'Open Sans Condensed',
	'weights' => array('300', '300 italic', 'bold', 'bold italic'),
	'subsets' => array('greek', 'vietnamese', 'greek-ext', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Oranienbaum' => array(
	'family'  => 'Oranienbaum',
	'weights' => array('normal'),
	'subsets' => array('cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Orbitron' => array(
	'family'  => 'Orbitron',
	'weights' => array('normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Oregano' => array(
	'family'  => 'Oregano',
	'weights' => array('normal', 'italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Orienta' => array(
	'family'  => 'Orienta',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Original Surfer' => array(
	'family'  => 'Original Surfer',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Oswald' => array(
	'family'  => 'Oswald',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('vietnamese', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Over the Rainbow' => array(
	'family'  => 'Over the Rainbow',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Overlock' => array(
	'family'  => 'Overlock',
	'weights' => array('normal', 'italic', 'bold', 'bold italic', '900', '900 italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Overlock SC' => array(
	'family'  => 'Overlock SC',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Overpass' => array(
	'family'  => 'Overpass',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', 'italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Overpass Mono' => array(
	'family'  => 'Overpass Mono',
	'weights' => array('300', '300 italic', 'normal', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Ovo' => array(
	'family'  => 'Ovo',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Oxygen' => array(
	'family'  => 'Oxygen',
	'weights' => array('300', '300 italic', 'normal', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Oxygen Mono' => array(
	'family'  => 'Oxygen Mono',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'PT Mono' => array(
	'family'  => 'PT Mono',
	'weights' => array('normal'),
	'subsets' => array('cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'PT Sans' => array(
	'family'  => 'PT Sans',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'PT Sans Caption' => array(
	'family'  => 'PT Sans Caption',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'PT Sans Narrow' => array(
	'family'  => 'PT Sans Narrow',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'PT Serif' => array(
	'family'  => 'PT Serif',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'PT Serif Caption' => array(
	'family'  => 'PT Serif Caption',
	'weights' => array('normal', 'italic'),
	'subsets' => array('cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Pacifico' => array(
	'family'  => 'Pacifico',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Padauk' => array(
	'family'  => 'Padauk',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('myanmar', 'latin'),
	'gf'      => true,
),
'Palanquin' => array(
	'family'  => 'Palanquin',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('devanagari', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Palanquin Dark' => array(
	'family'  => 'Palanquin Dark',
	'weights' => array('normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('devanagari', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Pangolin' => array(
	'family'  => 'Pangolin',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Paprika' => array(
	'family'  => 'Paprika',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Parisienne' => array(
	'family'  => 'Parisienne',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Passero One' => array(
	'family'  => 'Passero One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Passion One' => array(
	'family'  => 'Passion One',
	'weights' => array('normal', 'bold', 'bold italic', '900', '900 italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Pathway Gothic One' => array(
	'family'  => 'Pathway Gothic One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Patrick Hand' => array(
	'family'  => 'Patrick Hand',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Patrick Hand SC' => array(
	'family'  => 'Patrick Hand SC',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Pattaya' => array(
	'family'  => 'Pattaya',
	'weights' => array('normal'),
	'subsets' => array('thai', 'vietnamese', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Patua One' => array(
	'family'  => 'Patua One',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Pavanam' => array(
	'family'  => 'Pavanam',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext', 'tamil'),
	'gf'      => true,
),
'Paytone One' => array(
	'family'  => 'Paytone One',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Peddana' => array(
	'family'  => 'Peddana',
	'weights' => array('normal'),
	'subsets' => array('telugu', 'latin'),
	'gf'      => true,
),
'Peralta' => array(
	'family'  => 'Peralta',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Permanent Marker' => array(
	'family'  => 'Permanent Marker',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Petit Formal Script' => array(
	'family'  => 'Petit Formal Script',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Petrona' => array(
	'family'  => 'Petrona',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Philosopher' => array(
	'family'  => 'Philosopher',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('vietnamese', 'cyrillic-ext', 'latin', 'cyrillic'),
	'gf'      => true,
),
'Piedra' => array(
	'family'  => 'Piedra',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Pinyon Script' => array(
	'family'  => 'Pinyon Script',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Pirata One' => array(
	'family'  => 'Pirata One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Plaster' => array(
	'family'  => 'Plaster',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Play' => array(
	'family'  => 'Play',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('greek', 'vietnamese', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Playball' => array(
	'family'  => 'Playball',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Playfair Display' => array(
	'family'  => 'Playfair Display',
	'weights' => array('normal', 'italic', 'bold', 'bold italic', '900', '900 italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Playfair Display SC' => array(
	'family'  => 'Playfair Display SC',
	'weights' => array('normal', 'italic', 'bold', 'bold italic', '900', '900 italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Podkova' => array(
	'family'  => 'Podkova',
	'weights' => array('normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic'),
	'subsets' => array('vietnamese', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Poiret One' => array(
	'family'  => 'Poiret One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Poller One' => array(
	'family'  => 'Poller One',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Poly' => array(
	'family'  => 'Poly',
	'weights' => array('normal', 'italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Pompiere' => array(
	'family'  => 'Pompiere',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Pontano Sans' => array(
	'family'  => 'Pontano Sans',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Poor Story' => array(
	'family'  => 'Poor Story',
	'weights' => array('normal'),
	'subsets' => array('korean', 'latin'),
	'gf'      => true,
),
'Poppins' => array(
	'family'  => 'Poppins',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('devanagari', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Port Lligat Sans' => array(
	'family'  => 'Port Lligat Sans',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Port Lligat Slab' => array(
	'family'  => 'Port Lligat Slab',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Pragati Narrow' => array(
	'family'  => 'Pragati Narrow',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('devanagari', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Prata' => array(
	'family'  => 'Prata',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'cyrillic-ext', 'latin', 'cyrillic'),
	'gf'      => true,
),
'Preahvihear' => array(
	'family'  => 'Preahvihear',
	'weights' => array('normal'),
	'subsets' => array('khmer'),
	'gf'      => true,
),
'Press Start 2P' => array(
	'family'  => 'Press Start 2P',
	'weights' => array('normal'),
	'subsets' => array('greek', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Pridi' => array(
	'family'  => 'Pridi',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('thai', 'vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Princess Sofia' => array(
	'family'  => 'Princess Sofia',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Prociono' => array(
	'family'  => 'Prociono',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Prompt' => array(
	'family'  => 'Prompt',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('thai', 'vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Prosto One' => array(
	'family'  => 'Prosto One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Proza Libre' => array(
	'family'  => 'Proza Libre',
	'weights' => array('normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Public Sans' => array(
	'family'  => 'Public Sans',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic', 'italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Puritan' => array(
	'family'  => 'Puritan',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Purple Purse' => array(
	'family'  => 'Purple Purse',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Quando' => array(
	'family'  => 'Quando',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Quantico' => array(
	'family'  => 'Quantico',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Quattrocento' => array(
	'family'  => 'Quattrocento',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Quattrocento Sans' => array(
	'family'  => 'Quattrocento Sans',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Questrial' => array(
	'family'  => 'Questrial',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Quicksand' => array(
	'family'  => 'Quicksand',
	'weights' => array('300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Quintessential' => array(
	'family'  => 'Quintessential',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Qwigley' => array(
	'family'  => 'Qwigley',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Racing Sans One' => array(
	'family'  => 'Racing Sans One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Radley' => array(
	'family'  => 'Radley',
	'weights' => array('normal', 'italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Rajdhani' => array(
	'family'  => 'Rajdhani',
	'weights' => array('300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('devanagari', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Rakkas' => array(
	'family'  => 'Rakkas',
	'weights' => array('normal'),
	'subsets' => array('arabic', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Raleway' => array(
	'family'  => 'Raleway',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Raleway Dots' => array(
	'family'  => 'Raleway Dots',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Ramabhadra' => array(
	'family'  => 'Ramabhadra',
	'weights' => array('normal'),
	'subsets' => array('telugu', 'latin'),
	'gf'      => true,
),
'Ramaraja' => array(
	'family'  => 'Ramaraja',
	'weights' => array('normal'),
	'subsets' => array('telugu', 'latin'),
	'gf'      => true,
),
'Rambla' => array(
	'family'  => 'Rambla',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Rammetto One' => array(
	'family'  => 'Rammetto One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Ranchers' => array(
	'family'  => 'Ranchers',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Rancho' => array(
	'family'  => 'Rancho',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Ranga' => array(
	'family'  => 'Ranga',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('devanagari', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Rasa' => array(
	'family'  => 'Rasa',
	'weights' => array('300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('gujarati', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Rationale' => array(
	'family'  => 'Rationale',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Ravi Prakash' => array(
	'family'  => 'Ravi Prakash',
	'weights' => array('normal'),
	'subsets' => array('telugu', 'latin'),
	'gf'      => true,
),
'Red Hat Display' => array(
	'family'  => 'Red Hat Display',
	'weights' => array('normal', 'italic', '500', '500 italic', 'bold', 'bold italic', '900', '900 italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Red Hat Text' => array(
	'family'  => 'Red Hat Text',
	'weights' => array('normal', 'italic', '500', '500 italic', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Redressed' => array(
	'family'  => 'Redressed',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Reem Kufi' => array(
	'family'  => 'Reem Kufi',
	'weights' => array('normal'),
	'subsets' => array('arabic', 'latin'),
	'gf'      => true,
),
'Reenie Beanie' => array(
	'family'  => 'Reenie Beanie',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Revalia' => array(
	'family'  => 'Revalia',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Rhodium Libre' => array(
	'family'  => 'Rhodium Libre',
	'weights' => array('normal'),
	'subsets' => array('devanagari', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Ribeye' => array(
	'family'  => 'Ribeye',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Ribeye Marrow' => array(
	'family'  => 'Ribeye Marrow',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Righteous' => array(
	'family'  => 'Righteous',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Risque' => array(
	'family'  => 'Risque',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Roboto' => array(
	'family'  => 'Roboto',
	'weights' => array('100', '100 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', 'bold', 'bold italic', '900', '900 italic'),
	'subsets' => array('greek', 'vietnamese', 'greek-ext', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Roboto Condensed' => array(
	'family'  => 'Roboto Condensed',
	'weights' => array('300', '300 italic', 'normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('greek', 'vietnamese', 'greek-ext', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Roboto Mono' => array(
	'family'  => 'Roboto Mono',
	'weights' => array('100', '100 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', 'bold', 'bold italic'),
	'subsets' => array('greek', 'vietnamese', 'greek-ext', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Roboto Slab' => array(
	'family'  => 'Roboto Slab',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('greek', 'vietnamese', 'greek-ext', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Rochester' => array(
	'family'  => 'Rochester',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Rock Salt' => array(
	'family'  => 'Rock Salt',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Rokkitt' => array(
	'family'  => 'Rokkitt',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Romanesco' => array(
	'family'  => 'Romanesco',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Ropa Sans' => array(
	'family'  => 'Ropa Sans',
	'weights' => array('normal', 'italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Rosario' => array(
	'family'  => 'Rosario',
	'weights' => array('300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', 'italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Rosarivo' => array(
	'family'  => 'Rosarivo',
	'weights' => array('normal', 'italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Rouge Script' => array(
	'family'  => 'Rouge Script',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Rozha One' => array(
	'family'  => 'Rozha One',
	'weights' => array('normal'),
	'subsets' => array('devanagari', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Rubik' => array(
	'family'  => 'Rubik',
	'weights' => array('300', '300 italic', 'normal', 'italic', '500', '500 italic', 'bold', 'bold italic', '900', '900 italic'),
	'subsets' => array('hebrew', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Rubik Mono One' => array(
	'family'  => 'Rubik Mono One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Ruda' => array(
	'family'  => 'Ruda',
	'weights' => array('normal', 'bold', 'bold italic', '900', '900 italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Rufina' => array(
	'family'  => 'Rufina',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Ruge Boogie' => array(
	'family'  => 'Ruge Boogie',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Ruluko' => array(
	'family'  => 'Ruluko',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Rum Raisin' => array(
	'family'  => 'Rum Raisin',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Ruslan Display' => array(
	'family'  => 'Ruslan Display',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Russo One' => array(
	'family'  => 'Russo One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Ruthie' => array(
	'family'  => 'Ruthie',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Rye' => array(
	'family'  => 'Rye',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Sacramento' => array(
	'family'  => 'Sacramento',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Sahitya' => array(
	'family'  => 'Sahitya',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('devanagari', 'latin'),
	'gf'      => true,
),
'Sail' => array(
	'family'  => 'Sail',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Saira' => array(
	'family'  => 'Saira',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Saira Condensed' => array(
	'family'  => 'Saira Condensed',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Saira Extra Condensed' => array(
	'family'  => 'Saira Extra Condensed',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Saira Semi Condensed' => array(
	'family'  => 'Saira Semi Condensed',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Saira Stencil One' => array(
	'family'  => 'Saira Stencil One',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Salsa' => array(
	'family'  => 'Salsa',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Sanchez' => array(
	'family'  => 'Sanchez',
	'weights' => array('normal', 'italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Sancreek' => array(
	'family'  => 'Sancreek',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Sansita' => array(
	'family'  => 'Sansita',
	'weights' => array('normal', 'italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Sarabun' => array(
	'family'  => 'Sarabun',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic'),
	'subsets' => array('thai', 'vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Sarala' => array(
	'family'  => 'Sarala',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('devanagari', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Sarina' => array(
	'family'  => 'Sarina',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Sarpanch' => array(
	'family'  => 'Sarpanch',
	'weights' => array('normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('devanagari', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Satisfy' => array(
	'family'  => 'Satisfy',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Sawarabi Gothic' => array(
	'family'  => 'Sawarabi Gothic',
	'weights' => array('normal'),
	'subsets' => array('japanese', 'vietnamese', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Sawarabi Mincho' => array(
	'family'  => 'Sawarabi Mincho',
	'weights' => array('normal'),
	'subsets' => array('japanese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Scada' => array(
	'family'  => 'Scada',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Scheherazade' => array(
	'family'  => 'Scheherazade',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('arabic', 'latin'),
	'gf'      => true,
),
'Schoolbell' => array(
	'family'  => 'Schoolbell',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Scope One' => array(
	'family'  => 'Scope One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Seaweed Script' => array(
	'family'  => 'Seaweed Script',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Secular One' => array(
	'family'  => 'Secular One',
	'weights' => array('normal'),
	'subsets' => array('hebrew', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Sedgwick Ave' => array(
	'family'  => 'Sedgwick Ave',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Sedgwick Ave Display' => array(
	'family'  => 'Sedgwick Ave Display',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Sevillana' => array(
	'family'  => 'Sevillana',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Seymour One' => array(
	'family'  => 'Seymour One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Shadows Into Light' => array(
	'family'  => 'Shadows Into Light',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Shadows Into Light Two' => array(
	'family'  => 'Shadows Into Light Two',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Shanti' => array(
	'family'  => 'Shanti',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Share' => array(
	'family'  => 'Share',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Share Tech' => array(
	'family'  => 'Share Tech',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Share Tech Mono' => array(
	'family'  => 'Share Tech Mono',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Shojumaru' => array(
	'family'  => 'Shojumaru',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Short Stack' => array(
	'family'  => 'Short Stack',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Shrikhand' => array(
	'family'  => 'Shrikhand',
	'weights' => array('normal'),
	'subsets' => array('gujarati', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Siemreap' => array(
	'family'  => 'Siemreap',
	'weights' => array('normal'),
	'subsets' => array('khmer'),
	'gf'      => true,
),
'Sigmar One' => array(
	'family'  => 'Sigmar One',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Signika' => array(
	'family'  => 'Signika',
	'weights' => array('300', '300 italic', 'normal', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Signika Negative' => array(
	'family'  => 'Signika Negative',
	'weights' => array('300', '300 italic', 'normal', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Simonetta' => array(
	'family'  => 'Simonetta',
	'weights' => array('normal', 'italic', '900', '900 italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Single Day' => array(
	'family'  => 'Single Day',
	'weights' => array('normal'),
	'subsets' => array('korean'),
	'gf'      => true,
),
'Sintony' => array(
	'family'  => 'Sintony',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Sirin Stencil' => array(
	'family'  => 'Sirin Stencil',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Six Caps' => array(
	'family'  => 'Six Caps',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Skranji' => array(
	'family'  => 'Skranji',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Slabo 13px' => array(
	'family'  => 'Slabo 13px',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Slabo 27px' => array(
	'family'  => 'Slabo 27px',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Slackey' => array(
	'family'  => 'Slackey',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Smokum' => array(
	'family'  => 'Smokum',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Smythe' => array(
	'family'  => 'Smythe',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Sniglet' => array(
	'family'  => 'Sniglet',
	'weights' => array('normal', '800', '800 italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Snippet' => array(
	'family'  => 'Snippet',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Snowburst One' => array(
	'family'  => 'Snowburst One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Sofadi One' => array(
	'family'  => 'Sofadi One',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Sofia' => array(
	'family'  => 'Sofia',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Solway' => array(
	'family'  => 'Solway',
	'weights' => array('300', '300 italic', 'normal', '500', '500 italic', 'bold', 'bold italic', '800', '800 italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Song Myung' => array(
	'family'  => 'Song Myung',
	'weights' => array('normal'),
	'subsets' => array('korean', 'latin'),
	'gf'      => true,
),
'Sonsie One' => array(
	'family'  => 'Sonsie One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Sorts Mill Goudy' => array(
	'family'  => 'Sorts Mill Goudy',
	'weights' => array('normal', 'italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Source Code Pro' => array(
	'family'  => 'Source Code Pro',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '900', '900 italic'),
	'subsets' => array('greek', 'vietnamese', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Source Sans Pro' => array(
	'family'  => 'Source Sans Pro',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', 'italic', '600', '600 italic', 'bold', 'bold italic', '900', '900 italic'),
	'subsets' => array('greek', 'vietnamese', 'greek-ext', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Source Serif Pro' => array(
	'family'  => 'Source Serif Pro',
	'weights' => array('normal', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Space Mono' => array(
	'family'  => 'Space Mono',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Special Elite' => array(
	'family'  => 'Special Elite',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Spectral' => array(
	'family'  => 'Spectral',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Spectral SC' => array(
	'family'  => 'Spectral SC',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Spicy Rice' => array(
	'family'  => 'Spicy Rice',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Spinnaker' => array(
	'family'  => 'Spinnaker',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Spirax' => array(
	'family'  => 'Spirax',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Squada One' => array(
	'family'  => 'Squada One',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Sree Krushnadevaraya' => array(
	'family'  => 'Sree Krushnadevaraya',
	'weights' => array('normal'),
	'subsets' => array('telugu', 'latin'),
	'gf'      => true,
),
'Sriracha' => array(
	'family'  => 'Sriracha',
	'weights' => array('normal'),
	'subsets' => array('thai', 'vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Srisakdi' => array(
	'family'  => 'Srisakdi',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('thai', 'vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Staatliches' => array(
	'family'  => 'Staatliches',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Stalemate' => array(
	'family'  => 'Stalemate',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Stalinist One' => array(
	'family'  => 'Stalinist One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Stardos Stencil' => array(
	'family'  => 'Stardos Stencil',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Stint Ultra Condensed' => array(
	'family'  => 'Stint Ultra Condensed',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Stint Ultra Expanded' => array(
	'family'  => 'Stint Ultra Expanded',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Stoke' => array(
	'family'  => 'Stoke',
	'weights' => array('300', '300 italic', 'normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Strait' => array(
	'family'  => 'Strait',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Stylish' => array(
	'family'  => 'Stylish',
	'weights' => array('normal'),
	'subsets' => array('korean', 'latin'),
	'gf'      => true,
),
'Sue Ellen Francisco' => array(
	'family'  => 'Sue Ellen Francisco',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Suez One' => array(
	'family'  => 'Suez One',
	'weights' => array('normal'),
	'subsets' => array('hebrew', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Sulphur Point' => array(
	'family'  => 'Sulphur Point',
	'weights' => array('300', '300 italic', 'normal', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Sumana' => array(
	'family'  => 'Sumana',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('devanagari', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Sunflower' => array(
	'family'  => 'Sunflower',
	'weights' => array('300', '300 italic', '500', '500 italic', 'bold', 'bold italic'),
	'subsets' => array('korean', 'latin'),
	'gf'      => true,
),
'Sunshiney' => array(
	'family'  => 'Sunshiney',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Supermercado One' => array(
	'family'  => 'Supermercado One',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Sura' => array(
	'family'  => 'Sura',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('devanagari', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Suranna' => array(
	'family'  => 'Suranna',
	'weights' => array('normal'),
	'subsets' => array('telugu', 'latin'),
	'gf'      => true,
),
'Suravaram' => array(
	'family'  => 'Suravaram',
	'weights' => array('normal'),
	'subsets' => array('telugu', 'latin'),
	'gf'      => true,
),
'Suwannaphum' => array(
	'family'  => 'Suwannaphum',
	'weights' => array('normal'),
	'subsets' => array('khmer'),
	'gf'      => true,
),
'Swanky and Moo Moo' => array(
	'family'  => 'Swanky and Moo Moo',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Syncopate' => array(
	'family'  => 'Syncopate',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Tajawal' => array(
	'family'  => 'Tajawal',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('arabic', 'latin'),
	'gf'      => true,
),
'Tangerine' => array(
	'family'  => 'Tangerine',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Taprom' => array(
	'family'  => 'Taprom',
	'weights' => array('normal'),
	'subsets' => array('khmer'),
	'gf'      => true,
),
'Tauri' => array(
	'family'  => 'Tauri',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Taviraj' => array(
	'family'  => 'Taviraj',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('thai', 'vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Teko' => array(
	'family'  => 'Teko',
	'weights' => array('300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('devanagari', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Telex' => array(
	'family'  => 'Telex',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Tenali Ramakrishna' => array(
	'family'  => 'Tenali Ramakrishna',
	'weights' => array('normal'),
	'subsets' => array('telugu', 'latin'),
	'gf'      => true,
),
'Tenor Sans' => array(
	'family'  => 'Tenor Sans',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Text Me One' => array(
	'family'  => 'Text Me One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Thasadith' => array(
	'family'  => 'Thasadith',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('thai', 'vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'The Girl Next Door' => array(
	'family'  => 'The Girl Next Door',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Tienne' => array(
	'family'  => 'Tienne',
	'weights' => array('normal', 'bold', 'bold italic', '900', '900 italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Tillana' => array(
	'family'  => 'Tillana',
	'weights' => array('normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic'),
	'subsets' => array('devanagari', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Timmana' => array(
	'family'  => 'Timmana',
	'weights' => array('normal'),
	'subsets' => array('telugu', 'latin'),
	'gf'      => true,
),
'Tinos' => array(
	'family'  => 'Tinos',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('greek', 'vietnamese', 'greek-ext', 'cyrillic-ext', 'hebrew', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Titan One' => array(
	'family'  => 'Titan One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Titillium Web' => array(
	'family'  => 'Titillium Web',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', 'italic', '600', '600 italic', 'bold', 'bold italic', '900', '900 italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Tomorrow' => array(
	'family'  => 'Tomorrow',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Trade Winds' => array(
	'family'  => 'Trade Winds',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Trirong' => array(
	'family'  => 'Trirong',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('thai', 'vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Trocchi' => array(
	'family'  => 'Trocchi',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Trochut' => array(
	'family'  => 'Trochut',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Trykker' => array(
	'family'  => 'Trykker',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Tulpen One' => array(
	'family'  => 'Tulpen One',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Turret Road' => array(
	'family'  => 'Turret Road',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', 'bold', 'bold italic', '800', '800 italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Ubuntu' => array(
	'family'  => 'Ubuntu',
	'weights' => array('300', '300 italic', 'normal', 'italic', '500', '500 italic', 'bold', 'bold italic'),
	'subsets' => array('greek', 'greek-ext', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Ubuntu Condensed' => array(
	'family'  => 'Ubuntu Condensed',
	'weights' => array('normal'),
	'subsets' => array('greek', 'greek-ext', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Ubuntu Mono' => array(
	'family'  => 'Ubuntu Mono',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('greek', 'greek-ext', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Ultra' => array(
	'family'  => 'Ultra',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Uncial Antiqua' => array(
	'family'  => 'Uncial Antiqua',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Underdog' => array(
	'family'  => 'Underdog',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Unica One' => array(
	'family'  => 'Unica One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'UnifrakturCook' => array(
	'family'  => 'UnifrakturCook',
	'weights' => array('bold', 'bold italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'UnifrakturMaguntia' => array(
	'family'  => 'UnifrakturMaguntia',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Unkempt' => array(
	'family'  => 'Unkempt',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Unlock' => array(
	'family'  => 'Unlock',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Unna' => array(
	'family'  => 'Unna',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'VT323' => array(
	'family'  => 'VT323',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Vampiro One' => array(
	'family'  => 'Vampiro One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Varela' => array(
	'family'  => 'Varela',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Varela Round' => array(
	'family'  => 'Varela Round',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'hebrew', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Vast Shadow' => array(
	'family'  => 'Vast Shadow',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Vesper Libre' => array(
	'family'  => 'Vesper Libre',
	'weights' => array('normal', '500', '500 italic', 'bold', 'bold italic', '900', '900 italic'),
	'subsets' => array('devanagari', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Vibes' => array(
	'family'  => 'Vibes',
	'weights' => array('normal'),
	'subsets' => array('arabic', 'latin'),
	'gf'      => true,
),
'Vibur' => array(
	'family'  => 'Vibur',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Vidaloka' => array(
	'family'  => 'Vidaloka',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Viga' => array(
	'family'  => 'Viga',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Voces' => array(
	'family'  => 'Voces',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Volkhov' => array(
	'family'  => 'Volkhov',
	'weights' => array('normal', 'italic', 'bold', 'bold italic'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Vollkorn' => array(
	'family'  => 'Vollkorn',
	'weights' => array('normal', 'italic', '600', '600 italic', 'bold', 'bold italic', '900', '900 italic'),
	'subsets' => array('greek', 'vietnamese', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Vollkorn SC' => array(
	'family'  => 'Vollkorn SC',
	'weights' => array('normal', '600', '600 italic', 'bold', 'bold italic', '900', '900 italic'),
	'subsets' => array('vietnamese', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Voltaire' => array(
	'family'  => 'Voltaire',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Waiting for the Sunrise' => array(
	'family'  => 'Waiting for the Sunrise',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Wallpoet' => array(
	'family'  => 'Wallpoet',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Walter Turncoat' => array(
	'family'  => 'Walter Turncoat',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Warnes' => array(
	'family'  => 'Warnes',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Wellfleet' => array(
	'family'  => 'Wellfleet',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Wendy One' => array(
	'family'  => 'Wendy One',
	'weights' => array('normal'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Wire One' => array(
	'family'  => 'Wire One',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Work Sans' => array(
	'family'  => 'Work Sans',
	'weights' => array('100', '100 italic', '200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic', '800', '800 italic', '900', '900 italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Yanone Kaffeesatz' => array(
	'family'  => 'Yanone Kaffeesatz',
	'weights' => array('200', '200 italic', '300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('vietnamese', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Yantramanav' => array(
	'family'  => 'Yantramanav',
	'weights' => array('100', '100 italic', '300', '300 italic', 'normal', '500', '500 italic', 'bold', 'bold italic', '900', '900 italic'),
	'subsets' => array('devanagari', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Yatra One' => array(
	'family'  => 'Yatra One',
	'weights' => array('normal'),
	'subsets' => array('devanagari', 'latin', 'latin-ext'),
	'gf'      => true,
),
'Yellowtail' => array(
	'family'  => 'Yellowtail',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Yeon Sung' => array(
	'family'  => 'Yeon Sung',
	'weights' => array('normal'),
	'subsets' => array('korean', 'latin'),
	'gf'      => true,
),
'Yeseva One' => array(
	'family'  => 'Yeseva One',
	'weights' => array('normal'),
	'subsets' => array('vietnamese', 'cyrillic-ext', 'latin', 'latin-ext', 'cyrillic'),
	'gf'      => true,
),
'Yesteryear' => array(
	'family'  => 'Yesteryear',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Yrsa' => array(
	'family'  => 'Yrsa',
	'weights' => array('300', '300 italic', 'normal', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'ZCOOL KuaiLe' => array(
	'family'  => 'ZCOOL KuaiLe',
	'weights' => array('normal'),
	'subsets' => array('latin', 'chinese-simplified'),
	'gf'      => true,
),
'ZCOOL QingKe HuangYou' => array(
	'family'  => 'ZCOOL QingKe HuangYou',
	'weights' => array('normal'),
	'subsets' => array('latin', 'chinese-simplified'),
	'gf'      => true,
),
'ZCOOL XiaoWei' => array(
	'family'  => 'ZCOOL XiaoWei',
	'weights' => array('normal'),
	'subsets' => array('latin', 'chinese-simplified'),
	'gf'      => true,
),
'Zeyada' => array(
	'family'  => 'Zeyada',
	'weights' => array('normal'),
	'subsets' => array('latin'),
	'gf'      => true,
),
'Zhi Mang Xing' => array(
	'family'  => 'Zhi Mang Xing',
	'weights' => array('normal'),
	'subsets' => array('latin', 'chinese-simplified'),
	'gf'      => true,
),
'Zilla Slab' => array(
	'family'  => 'Zilla Slab',
	'weights' => array('300', '300 italic', 'normal', 'italic', '500', '500 italic', '600', '600 italic', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),
'Zilla Slab Highlight' => array(
	'family'  => 'Zilla Slab Highlight',
	'weights' => array('normal', 'bold', 'bold italic'),
	'subsets' => array('latin', 'latin-ext'),
	'gf'      => true,
),

);
